==> qtjambi-qt3drender-5.15.5-sources.jar: io/qt/qt3d/render/QTexture3D.java <==
package io.qt.qt3d.render;


/**
 * <p>A QAbstractTexture with a Target3D target format</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qt3drender-qtexture3d.html">Qt3DRender::QTexture3D</a></p>
 */
public class QTexture3D extends io.qt.qt3d.render.QAbstractTexture
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QTexture3D.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QTexture3D(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QTexture3D() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qtexture3d.html#QTexture3D">Qt3DRender::QTexture3D::QTexture3D(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QTexture3D(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QTexture3D instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QTexture3D(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QTexture3D(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QTexture3D instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-5.15.10-sources.jar: io/qt/qt3d/render/QTexture3D.java <==
package io.qt.qt3d.render;


/**
 * <p>A QAbstractTexture with a Target3D target format</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3drender-qtexture3d.html">Qt3DRender::QTexture3D</a></p>
 */
public class QTexture3D extends io.qt.qt3d.render.QAbstractTexture
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QTexture3D.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QTexture3D(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QTexture3D() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qtexture3d.html#QTexture3D">Qt3DRender::QTexture3D::QTexture3D(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QTexture3D(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QTexture3D instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QTexture3D(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QTexture3D(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QTexture3D instance, QDeclarativeConstructor constructor);
    
}
